@@ -10,5 +10,7 @@ def check_case(args):
     else:
         raise ValueError(('Incorrect value for Kasua. Read README.md or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information'))
 
+def analyze():
+    return None
 
 #analyze({"Aditza":None, "Kasua":"NOR-NORK", "Modua":"Ahalera","Denbora":"Oraina", "Nor":"zuek", "Nori":None, "Nork":"hark"})
\ No newline at end of file
